pub struct EvidenceBundlePayload {
pub protocol_version: u16,
pub bundle_id: [u8; 16],
pub license_request: Vec<u8>,
pub license_grant: Vec<u8>,
pub receipt: Vec<u8>,
pub binding_certificate: Vec<u8>,
pub terms_hash: [u8; 32],
pub consent: ConsentRecord,
pub payment_reference: String,
pub tsa_token: Vec<u8>,
pub vendor_public_key: [u8; 32],
pub customer_public_key: [u8; 32],
}Fields
protocol_version: u16bundle_id: [u8; 16]license_request: Vec<u8>license_grant: Vec<u8>receipt: Vec<u8>binding_certificate: Vec<u8>terms_hash: [u8; 32]hash of the exact terms text shown at purchase, vendor must produce the original to verify
consent: ConsentRecordpayment_reference: Stringtsa_token: Vec<u8>vendor_public_key: [u8; 32]customer_public_key: [u8; 32]Trait Implementations
Sourceimpl Clone for EvidenceBundlePayload
impl Clone for EvidenceBundlePayload
Sourcefn clone(&self) -> EvidenceBundlePayload
fn clone(&self) -> EvidenceBundlePayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvidenceBundlePayload
impl Debug for EvidenceBundlePayload
Sourceimpl<'de> Deserialize<'de> for EvidenceBundlePayload
impl<'de> Deserialize<'de> for EvidenceBundlePayload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EvidenceBundlePayload
impl PartialEq for EvidenceBundlePayload
Sourcefn eq(&self, other: &EvidenceBundlePayload) -> bool
fn eq(&self, other: &EvidenceBundlePayload) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EvidenceBundlePayload
impl Serialize for EvidenceBundlePayload
impl Eq for EvidenceBundlePayload
impl StructuralPartialEq for EvidenceBundlePayload