pub fn compute_commitment(identifiers: &[HardwareIdentifier]) -> [u8; 32]Expand description
Stable hash of the given identifiers, sorted by kind so collection order doesn’t matter.
pub fn compute_commitment(identifiers: &[HardwareIdentifier]) -> [u8; 32]Stable hash of the given identifiers, sorted by kind so collection order doesn’t matter.